==> groundx-2.8.25.tar.gz: groundx-2.8.25/src/groundx/extract/classes/prompt.py <==
import typing

from pydantic import BaseModel

from ..utility import str_to_type_sequence


class Prompt(BaseModel):
    attr_name: typing.Optional[str] = None
    description: typing.Optional[str] = None
    display_name: typing.Optional[str] = None
    prompt: str
    type: typing.Optional[typing.Union[str, typing.List[str]]] = None

    class Config:
        validate_by_name = True

    def key(self) -> str:
        if self.attr_name:
            return self.attr_name

        if self.display_name:
            return self.display_name

        raise ValueError(f"missing attr_name or display_name")

    def prompt_name(self) -> str:
        if self.display_name:
            return self.display_name

        if self.attr_name:
            return self.attr_name

        raise ValueError(f"missing attr_name or display_name")

    def valid_value(self, value: typing.Any) -> bool:
        ty = self.type
        if not ty:
            return True

        types: typing.List[typing.Type[typing.Any]] = []
        if isinstance(ty, list):
            for t in ty:
                if t == "int" or t == "float":
                    types.extend([int, float])
                elif t == "str":
                    types.append(str)

            return isinstance(value, tuple(types))

        exp = str_to_type_sequence(ty)
        for et in exp:
            if et in (int, float):
                types.extend([int, float])
            else:
                types.append(et)
        types = list(dict.fromkeys(types))
        return isinstance(value, tuple(types))

==> groundx-2.8.36.tar.gz: groundx-2.8.36/src/groundx/extract/classes/prompt.py <==
import typing

from pydantic import BaseModel

from ..utility import str_to_type_sequence


class Prompt(BaseModel):
    attr_name: typing.Optional[str] = None
    short: typing.Optional[str] = None
    display_name: typing.Optional[str] = None
    full: str
    required: bool = False
    type: typing.Optional[typing.Union[str, typing.List[str]]] = None

    class Config:
        validate_by_name = True

    @property
    def description(self) -> typing.Optional[str]:
        return self.short

    def key(self) -> str:
        if self.attr_name:
            return self.attr_name

        if self.display_name:
            return self.display_name

        raise ValueError(f"missing attr_name or display_name")

    @property
    def prompt(self) -> str:
        return self.full

    def prompt_name(self) -> str:
        if self.display_name:
            return self.display_name

        if self.attr_name:
            return self.attr_name

        raise ValueError(f"missing attr_name or display_name")

    def valid_value(self, value: typing.Any) -> bool:
        ty = self.type
        if not ty:
            return True

        types: typing.List[typing.Type[typing.Any]] = []
        if isinstance(ty, list):
            for t in ty:
                if t == "int" or t == "float":
                    types.extend([int, float])
                elif t == "str":
                    types.append(str)

            return isinstance(value, tuple(types))

        exp = str_to_type_sequence(ty)
        for et in exp:
            if et in (int, float):
                types.extend([int, float])
            else:
                types.append(et)
        types = list(dict.fromkeys(types))
        return isinstance(value, tuple(types))
